@@ -540,6 +540,59 @@ is_dir(const gchar *path)
 	return result;
 }
 
+static GList*
+collect_file_path(GDir *dir, const gchar *prefix, gchar *dir_name,
+		  gchar *base_name, guint max)
+{
+	GList *list = g_list_alloc();
+	gchar *dir_base_name = g_path_get_basename(dir_name);
+	gboolean is_dir_path = (strcmp(base_name, dir_base_name) == 0);
+	const gchar *name;
+	gchar *full_path;
+	gchar *utf8_full_path;
+	gchar *full_uri;
+	gchar *separator;
+	guint capacity = max;
+			
+	for (name = g_dir_read_name(dir);
+	     name && capacity > 0;
+	     name = g_dir_read_name(dir))
+	{
+		if (!is_dir_path &&
+		    strncmp(base_name, name, strlen(base_name)) != 0)
+			continue;
+				
+		full_path = g_build_filename(dir_name, name, NULL);
+		separator = is_dir(full_path) ? G_DIR_SEPARATOR_S : NULL;
+		if ((g_utf8_validate(full_path, -1, NULL)))
+		{
+			utf8_full_path = full_path;
+		}
+		else
+		{
+			utf8_full_path = g_filename_to_utf8(full_path,
+							    -1,
+							    NULL,
+							    NULL,
+							    NULL);
+			g_free(full_path);
+			if (!utf8_full_path) continue;
+		}
+					
+		full_uri = g_strconcat(prefix, utf8_full_path,
+				       separator, NULL);
+		list = g_list_append(list, full_uri);
+
+		g_free(utf8_full_path);
+
+		capacity--;
+	}
+
+	g_free(dir_base_name);
+	
+	return list;
+}
+
 static void
 kz_location_entry_action_add_file_path_to_history(KzLocationEntryAction *action,
 						  const gchar *path,
@@ -553,38 +606,17 @@ kz_location_entry_action_add_file_path_to_history(KzLocationEntryAction *action,
 
 	if (dir)
 	{
-		GList *list = g_list_alloc();
-		gchar *dir_base_name = g_path_get_basename(dir_name);
-		gboolean is_dir_path = (strcmp(base_name, dir_base_name) == 0);
-		const gchar *name;
-		gchar *full_path;
-		gchar *full_uri;
-			
-		for (name = g_dir_read_name(dir);
-		     name;
-		     name = g_dir_read_name(dir))
-		{
-			
-			if (!is_dir_path &&
-			    strncmp(base_name, name, strlen(base_name)) != 0)
-				continue;
-				
-			full_path = g_build_filename(dir_name, name, NULL);
-			full_uri = g_strconcat(prefix, full_path,
-					       is_dir(full_path) ? G_DIR_SEPARATOR_S : NULL,
-					       NULL);
-			list = g_list_append(list, full_uri);
-			
-			g_free(full_path);
-		}
-		
-		g_dir_close(dir);
+		guint max = kz_history_action_get_max_history
+			(KZ_HISTORY_ACTION(action));
+		GList *list = collect_file_path(dir, prefix, dir_name,
+						base_name, max);
 
+		g_dir_close(dir);
+		
 		g_list_concat(list,
 			      kz_history_action_get_history(KZ_HISTORY_ACTION(action)));
 		kz_history_action_set_history(KZ_HISTORY_ACTION(action), list);
 
-		g_free(dir_base_name);
 		g_list_foreach(list, (GFunc)g_free, NULL);
 		g_list_free(list);
 	}
