@@ -32,6 +32,7 @@
 #include "gobject-utils.h"
 #include "kz-entry.h"
 #include "kz-actions.h"
+#include "kz-icons.h"
 
 #define KZ_SMART_BOOKMARK_ACTION_BOOKMARK_KEY "KzSmartBookmarkAction::Bookmark"
 
@@ -410,8 +411,12 @@ static gboolean
 cb_entry_key_press (GtkWidget *widget, GdkEventKey *event,
 		    KzSmartBookmarkAction *action)
 {
+	guint new_tab_mask = GDK_CONTROL_MASK;
+
+	KZ_CONF_GET("Tab" , "new_tab_mask" , new_tab_mask , INT);
+
 	if ((event->keyval == GDK_Return || event->keyval == GDK_ISO_Enter)
-	    && (event->state & GDK_CONTROL_MASK))
+	    && (event->state & new_tab_mask))
 	{
 		gboolean newtab;
 		gchar *smart_uri;
@@ -740,7 +745,7 @@ cb_entry_icon_pressed  (GtkEntry *entry, GdkEventButton *event,
 	gtk_menu_popup(GTK_MENU(action->menu), NULL, NULL, 
 		       menu_position_under_widget,
 		       GTK_WIDGET(entry),
-		       0, event->time);
+		       0, 0);
 }
 
 
