@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark.c,v 1.77 2005/07/13 05:37:06 ikezoe Exp $
+ *  $Id: kz-bookmark.c,v 1.78 2005/09/23 12:16:08 tyuyu Exp $
  */
 
 #include "kz-bookmark.h"
@@ -55,7 +55,8 @@ enum {
 	PROP_INTERVAL,
 	PROP_CURRENT_POS,
 	PROP_LOCK,
-	PROP_AUTO_REFRESH
+	PROP_AUTO_REFRESH,
+	PROP_JAVASCRIPT
 };
 
 
@@ -93,6 +94,7 @@ static GQuark children_quark          = 0;
 static GQuark current_pos_quark       = 0;
 static GQuark lock_quark              = 0;
 static GQuark auto_refresh_quark      = 0;
+static GQuark javascript_quark        = 0;
 
 GType
 kz_bookmark_type_get_type (void)
@@ -264,6 +266,16 @@ kz_bookmark_class_init (KzBookmarkClass *klass)
 			 FALSE,
 			 G_PARAM_READWRITE));
 
+	g_object_class_install_property(
+		object_class,
+		PROP_JAVASCRIPT,
+		g_param_spec_boolean(
+			 "javascript",
+			 _("Javascript state"),
+			 _("Javascript state for tab"),
+			 FALSE,
+			 G_PARAM_READWRITE));
+
 	kz_bookmark_signals[INSERT_CHILD_SIGNAL]
 		= g_signal_new ("insert-child",
 				G_TYPE_FROM_CLASS (klass),
@@ -327,6 +339,7 @@ kz_bookmark_class_init (KzBookmarkClass *klass)
 	current_pos_quark  = g_quark_from_string("KzBookmark::Current");
 	lock_quark         = g_quark_from_string("KzBookmark::Lock");
 	auto_refresh_quark = g_quark_from_string("KzBookmark::AutoRefresh");
+	javascript_quark   = g_quark_from_string("KzBookmark::Javascript");
 }
 
 static void
@@ -419,6 +432,11 @@ kz_bookmark_set_property (GObject *object,
 		g_object_set_qdata(object, auto_refresh_quark,
 				   GINT_TO_POINTER(g_value_get_boolean(value)));
 		break;
+	case PROP_JAVASCRIPT:
+		g_return_if_fail(kz_bookmark_is_folder(bookmark));
+		g_object_set_qdata(object, javascript_quark,
+				   GINT_TO_POINTER(g_value_get_boolean(value)));
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 		break;
@@ -490,6 +508,11 @@ kz_bookmark_get_property (GObject *object,
 							  auto_refresh_quark));
 		g_value_set_boolean(value, time);
 		break;
+	case PROP_JAVASCRIPT:
+		time = GPOINTER_TO_INT(g_object_get_qdata(object,
+							  javascript_quark));
+		g_value_set_boolean(value, time);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 		break;
@@ -1026,6 +1049,24 @@ kz_bookmark_set_auto_refresh (KzBookmark  *bookmark,
 	g_object_set(G_OBJECT(bookmark), "auto-refresh", auto_refresh, NULL);
 }
 
+gboolean
+kz_bookmark_get_javascript (KzBookmark  *bookmark)
+{
+	if (!kz_bookmark_is_folder(bookmark)) return FALSE;
+
+	return GPOINTER_TO_INT(g_object_get_qdata(G_OBJECT(bookmark),
+						  javascript_quark));
+}
+
+void
+kz_bookmark_set_javascript (KzBookmark  *bookmark,
+			      gboolean javascript)
+{
+	if (!kz_bookmark_is_folder(bookmark)) return;
+
+	g_object_set(G_OBJECT(bookmark), "javascript", javascript, NULL);
+}
+
 static gint 
 compare_func (gconstpointer a, gconstpointer b)
 {
