@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark.h,v 1.33 2005/07/08 09:06:22 ikezoe Exp $
+ *  $Id: kz-bookmark.h,v 1.34 2005/09/23 12:16:08 tyuyu Exp $
  */
 
 #ifndef __KZ_BOOKMARK_H__
@@ -157,6 +157,9 @@ void		kz_bookmark_set_lock		(KzBookmark  *bookmark,
 gboolean	kz_bookmark_get_auto_refresh	(KzBookmark  *bookmark);
 void		kz_bookmark_set_auto_refresh	(KzBookmark  *bookmark,
 						 gboolean auto_refresh);
+gboolean	kz_bookmark_get_javascript	(KzBookmark  *bookmark);
+void		kz_bookmark_set_javascript	(KzBookmark  *bookmark,
+						 gboolean javascript);
 
 void		kz_bookmark_regist_sort_func	(const gchar *type,
 						 GCompareFunc *func);
