@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-xbel.c,v 1.64 2005/07/13 00:14:55 ikezoe Exp $
+ *  $Id: kz-xbel.c,v 1.66 2005/09/23 12:44:56 tyuyu Exp $
  */
 
 #include "kazehakase.h"
@@ -391,6 +391,13 @@ parse_metadata_node (KzBookmark *bookmark, KzXMLNode *parent)
 				if (!strcmp(attr->value, "yes"))
 					kz_bookmark_set_auto_refresh(bookmark, TRUE);
 			}
+			else if (!strncmp(attr->name, "kz:javascript", 13))
+			{
+				if (!strcmp(attr->value, "yes"))
+					kz_bookmark_set_javascript(bookmark, TRUE);
+				if (!strcmp(attr->value, "no"))
+					kz_bookmark_set_javascript(bookmark, FALSE);
+			}
 		}
 
 		if (smart_regex && smart_uri)
@@ -1026,6 +1033,7 @@ create_xml_node (KzBookmark *bookmark)
 		gint pos = kz_bookmark_get_current(bookmark);
 		gboolean lock = kz_bookmark_get_lock(bookmark);
 		gboolean auto_refresh = kz_bookmark_get_auto_refresh(bookmark);
+		gboolean javascript = kz_bookmark_get_javascript(bookmark);
 		/*
 		 * <folder>\n
 		 * <title/>
@@ -1054,23 +1062,40 @@ create_xml_node (KzBookmark *bookmark)
 			}
 			if (lock)
 			{
-				const gchar *str;
-				if (lock)
-					str = "yes";
-				else
-					str = "no";
-				kz_xml_node_set_attr(metanode, "kz:lock", str);
+				kz_xml_node_set_attr(metanode, "kz:lock", "yes");
 			}
 			if (auto_refresh)
 			{
-				const gchar *str;
-				if (auto_refresh)
-					str = "yes";
-				else
-					str = "no";
-				kz_xml_node_set_attr(metanode, "kz:auto_refresh", str);
+				kz_xml_node_set_attr(metanode, "kz:auto_refresh", "yes");
 			}
+		}
 
+		if (javascript)
+		{
+			const gchar *str;
+				str = "yes";
+			metanode = xml_node_find_metadata_node(node);
+	
+			if (!metanode)
+				metanode = xml_node_append_metadata_node(node);
+			kz_xml_node_set_attr(metanode, "kz:javascript", str);
+		}
+		else
+		{
+			gboolean javascript_default = TRUE;
+			const gchar *str;
+
+			metanode = xml_node_find_metadata_node(node);
+			if (!metanode)
+				metanode = xml_node_append_metadata_node(node);
+
+			KZ_CONF_GET("Global", "use_javascript", javascript_default, BOOL);
+
+			if(javascript_default)
+				str = "yes";
+			else
+				str = "no";
+			kz_xml_node_set_attr(metanode, "kz:javascript", str);
 		}
 	}
 	else if (KZ_IS_SMART_BOOKMARK(bookmark))
@@ -1476,6 +1501,24 @@ cb_bookmark_notify (GObject *object, GParamSpec *pspec)
 
 		kz_xml_node_set_attr(metanode, "kz:auto_refresh", str);
 	}
+	else if (!strcmp(prop, "javascript"))
+	{
+		KzXMLNode *metanode;
+		const gchar *str;
+		gboolean javascript = g_value_get_boolean(&value);
+		
+		if (javascript)
+			str = "yes";
+		else
+			str = "no";
+
+		metanode = xml_node_find_metadata_node(node);
+	
+		if (!metanode)
+			metanode = xml_node_append_metadata_node(node);
+
+		kz_xml_node_set_attr(metanode, "kz:javascript", str);
+	}
 	g_value_unset(&value);
 }
 
