@@ -23,6 +23,7 @@
 
 #include <glib/gi18n.h>
 #include "gobject-utils.h"
+#include "kz-icons.h"
 
 enum {
 	PROP_0,
@@ -30,7 +31,8 @@ enum {
 };
 
 
-struct _KzPrintDialogPriv
+typedef struct _KzPrintDialogPrivate	KzPrintDialogPrivate;
+struct _KzPrintDialogPrivate
 {
 	GtkWidget     *to_file;
 	GtkWidget     *filename;
@@ -42,6 +44,7 @@ struct _KzPrintDialogPriv
 	GtkWidget     *to_page;
 	GtkWidget     *printer_list;
 };
+#define KZ_PRINT_DIALOG_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), KZ_TYPE_PRINT_DIALOG, KzPrintDialogPrivate))
 
 static void     kz_print_dialog_class_init         (KzPrintDialogClass *klass);
 static void     kz_print_dialog_init               (KzPrintDialog  *print);
@@ -96,6 +99,7 @@ kz_print_dialog_class_init (KzPrintDialogClass *klass)
 				     KZ_TYPE_WINDOW,
 				     G_PARAM_READWRITE |
 				     G_PARAM_CONSTRUCT_ONLY));
+	g_type_class_add_private (gobject_class, sizeof(KzPrintDialogPrivate));
 }
 
 
@@ -108,12 +112,12 @@ kz_print_dialog_init (KzPrintDialog *print)
 	GtkWidget *combo_box;
 	GtkAdjustment *adj;
 	gchar *default_filename;
+	KzPrintDialogPrivate *priv = KZ_PRINT_DIALOG_GET_PRIVATE (print);
 
 	default_filename = g_build_filename(g_get_current_dir(), 
 					    "file.ps", NULL);
 	
 	print->kz = NULL;
-	print->priv = g_new0(KzPrintDialogPriv, 1);
 	
 	main_vbox = GTK_DIALOG(print)->vbox;
 	gtk_box_set_spacing(GTK_BOX(main_vbox), 4);
@@ -148,7 +152,7 @@ kz_print_dialog_init (KzPrintDialog *print)
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio1), TRUE);
 	gtk_box_pack_start(GTK_BOX(hbox), radio1, FALSE, FALSE, 2);
 
-	print->priv->printer_list = combo_box = gtk_combo_box_new_text();
+	priv->printer_list = combo_box = gtk_combo_box_new_text();
 	gtk_box_pack_start(GTK_BOX(hbox), combo_box,
 			   FALSE, FALSE, 0);
 	gtk_widget_show(combo_box);
@@ -157,17 +161,17 @@ kz_print_dialog_init (KzPrintDialog *print)
 	gtk_container_set_border_width(GTK_CONTAINER(hbox), 0);
 	gtk_container_add(GTK_CONTAINER(vbox), hbox);
 	gtk_widget_show(hbox);
-	print->priv->to_file = radio2 =
+	priv->to_file = radio2 =
 		gtk_radio_button_new_with_mnemonic_from_widget(
 		 	GTK_RADIO_BUTTON(radio1),
 			_("File"));
 	gtk_box_pack_start(GTK_BOX(hbox), radio2, FALSE, FALSE, 2);
 
-	print->priv->filename = entry = gtk_entry_new();
+	priv->filename = entry = gtk_entry_new();
 	gtk_entry_set_text(GTK_ENTRY(entry), default_filename);
 	gtk_widget_show(entry);
 	gtk_widget_set_sensitive(entry, FALSE);
-	print->priv->saveas = button = 
+	priv->saveas = button = 
 			gtk_button_new_from_stock(GTK_STOCK_SAVE_AS);
 	g_signal_connect(button, "clicked",
 			 G_CALLBACK(cb_save_as_button_clicked), print);
@@ -194,12 +198,12 @@ kz_print_dialog_init (KzPrintDialog *print)
 	gtk_container_add(GTK_CONTAINER(frame), vbox);
 	gtk_widget_show(vbox);
 	
-	print->priv->all_pages = radio1 = 
+	priv->all_pages = radio1 = 
 		gtk_radio_button_new_with_mnemonic(NULL,
 						  _("All Pages"));
 	gtk_box_pack_start(GTK_BOX(vbox), radio1, TRUE, TRUE, 2);
 	
-	print->priv->specified_pages = radio2 =
+	priv->specified_pages = radio2 =
 		gtk_radio_button_new_with_mnemonic_from_widget(
 		 	GTK_RADIO_BUTTON(radio1),
 			_("Pages"));
@@ -209,7 +213,7 @@ kz_print_dialog_init (KzPrintDialog *print)
 	gtk_widget_show(label);
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 2);	
 	
-	print->priv->from_page = spin =
+	priv->from_page = spin =
 			gtk_spin_button_new_with_range(0, 1000, 1);
 	adj = gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON(spin));
 	gtk_widget_show(spin);
@@ -219,7 +223,7 @@ kz_print_dialog_init (KzPrintDialog *print)
 	label = gtk_label_new(_("to"));
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 2);	
 	gtk_widget_show(label);
-	print->priv->to_page = spin =
+	priv->to_page = spin =
 			gtk_spin_button_new_with_range(0, 1000, 1);
 	adj = gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON(spin));
 	gtk_widget_show(spin);
@@ -230,7 +234,7 @@ kz_print_dialog_init (KzPrintDialog *print)
 	gtk_widget_show(hbox);
 	gtk_box_pack_start(GTK_BOX(vbox), hbox,   TRUE, TRUE, 2);
 	
-	print->priv->selection = radio3 =
+	priv->selection = radio3 =
 		gtk_radio_button_new_with_mnemonic_from_widget(
 		 	GTK_RADIO_BUTTON(radio1),
 			_("Selection"));
@@ -257,10 +261,12 @@ kz_print_dialog_constructor (GType                  type,
 	KzPrintDialog *print;
 	GObject *object;
 	GObjectClass *klass = G_OBJECT_CLASS(parent_class);
+	KzPrintDialogPrivate *priv;
 
 	object = klass->constructor(type, n_props, props);
 
 	print = KZ_PRINT_DIALOG(object);
+	priv = KZ_PRINT_DIALOG_GET_PRIVATE (print);
 	widget = GTK_WIDGET(print);
 
 	gtk_window_set_title(GTK_WINDOW(print), _("Print"));
@@ -275,11 +281,11 @@ kz_print_dialog_constructor (GType                  type,
 
 		for (node = g_list_first(printer_list); node; node = g_list_next(node))
 		{
-			gtk_combo_box_append_text(GTK_COMBO_BOX(print->priv->printer_list),
+			gtk_combo_box_append_text(GTK_COMBO_BOX(priv->printer_list),
 						  node->data);	
 		}
 
-		gtk_combo_box_set_active(GTK_COMBO_BOX(print->priv->printer_list),
+		gtk_combo_box_set_active(GTK_COMBO_BOX(priv->printer_list),
 					 0);
 
 		if (printer_list)
@@ -377,6 +383,7 @@ cb_save_as_button_clicked (GtkWidget *widget, KzPrintDialog *print)
 	GtkWidget *file_dialog;
 	gchar *selected_filename = NULL;
 	gint result;
+	KzPrintDialogPrivate *priv = KZ_PRINT_DIALOG_GET_PRIVATE (print);
 	
 	g_return_if_fail (KZ_IS_PRINT_DIALOG(print));
 
@@ -395,7 +402,7 @@ cb_save_as_button_clicked (GtkWidget *widget, KzPrintDialog *print)
 	{
 	 case GTK_RESPONSE_ACCEPT:
 		selected_filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(file_dialog));
-		gtk_entry_set_text(GTK_ENTRY(print->priv->filename),
+		gtk_entry_set_text(GTK_ENTRY(priv->filename),
 				   selected_filename);
 		break;
 	 default:
@@ -411,19 +418,22 @@ cb_save_as_button_clicked (GtkWidget *widget, KzPrintDialog *print)
 static void
 cb_print_to_file_toggled (GtkToggleButton *button, KzPrintDialog *print)
 {
+	KzPrintDialogPrivate *priv = KZ_PRINT_DIALOG_GET_PRIVATE (print);
 	gboolean active = gtk_toggle_button_get_active(button);
-	gtk_widget_set_sensitive(print->priv->filename, active);
-	gtk_widget_set_sensitive(print->priv->saveas, active);
-	gtk_widget_set_sensitive(print->priv->printer_list, !active);
+
+	gtk_widget_set_sensitive(priv->filename, active);
+	gtk_widget_set_sensitive(priv->saveas, active);
+	gtk_widget_set_sensitive(priv->printer_list, !active);
 }
 
 static void
 cb_print_pages_toggled (GtkToggleButton *button, KzPrintDialog *print)
 {
+	KzPrintDialogPrivate *priv = KZ_PRINT_DIALOG_GET_PRIVATE (print);
 	gboolean active = gtk_toggle_button_get_active(button);
 
-	gtk_widget_set_sensitive(print->priv->to_page, active);
-	gtk_widget_set_sensitive(print->priv->from_page, active);
+	gtk_widget_set_sensitive(priv->to_page, active);
+	gtk_widget_set_sensitive(priv->from_page, active);
 }
 
 PrintInfo *
@@ -433,14 +443,15 @@ kz_print_dialog_get_print_info (KzPrintDialog *print)
 	gboolean active;
   	GtkTreeIter iter;
 	gchar *text = NULL;
+	KzPrintDialogPrivate *priv = KZ_PRINT_DIALOG_GET_PRIVATE (print);
 
 	info = g_new0(PrintInfo, 1);
 
-  	if (gtk_combo_box_get_active_iter(GTK_COMBO_BOX(print->priv->printer_list),
+  	if (gtk_combo_box_get_active_iter(GTK_COMBO_BOX(priv->printer_list),
 	      				  &iter))
 	{
 		GtkTreeModel *model;
-		model = gtk_combo_box_get_model(GTK_COMBO_BOX(print->priv->printer_list));
+		model = gtk_combo_box_get_model(GTK_COMBO_BOX(priv->printer_list));
 		gtk_tree_model_get (model, &iter, 
 				    0, &text, -1);
 	}
@@ -448,28 +459,28 @@ kz_print_dialog_get_print_info (KzPrintDialog *print)
 	info->printer = text;
 
 	info->to_file   = gtk_toggle_button_get_active(
-				GTK_TOGGLE_BUTTON(print->priv->to_file));
+				GTK_TOGGLE_BUTTON(priv->to_file));
 	info->filename  = gtk_entry_get_text(
-				GTK_ENTRY(print->priv->filename)); 
+				GTK_ENTRY(priv->filename)); 
 	active = gtk_toggle_button_get_active(
-				GTK_TOGGLE_BUTTON(print->priv->all_pages));
+				GTK_TOGGLE_BUTTON(priv->all_pages));
 	if (active)
 		info->range = KZ_PRINT_RANGE_ALL_PAGES;
 	
 	active = gtk_toggle_button_get_active(
-				GTK_TOGGLE_BUTTON(print->priv->specified_pages));
+				GTK_TOGGLE_BUTTON(priv->specified_pages));
 	if (active)
 		info->range = KZ_PRINT_RANGE_SPECIFIED_PAGES;
 	
 	active = gtk_toggle_button_get_active(
-				GTK_TOGGLE_BUTTON(print->priv->selection));
+				GTK_TOGGLE_BUTTON(priv->selection));
 	if (active)
 		info->range = KZ_PRINT_RANGE_SELECTION;
 	
 	info->from_page = gtk_spin_button_get_value_as_int(
-				GTK_SPIN_BUTTON(print->priv->from_page));
+				GTK_SPIN_BUTTON(priv->from_page));
 	info->to_page   = gtk_spin_button_get_value_as_int(
-				GTK_SPIN_BUTTON(print->priv->to_page));
+				GTK_SPIN_BUTTON(priv->to_page));
 
 	print->info = info;
 
