@@ -35,22 +35,23 @@ enum {
 enum {
 	PROP_0,
 	PROP_URI,
-	PROP_FILENAME,
-	PROP_IO
+	PROP_FILENAME
 };
 
-static void kz_downloader_class_init   (KzDownloaderClass *klass);
-static void kz_downloader_init         (KzDownloader *downloader);
-static void kz_downloader_dispose      (GObject *object);
-
-static void kz_downloader_set_property (GObject *object,
-					guint prop_id,
-					const GValue *value,
-					GParamSpec *pspec);
-static void kz_downloader_get_property (GObject *object,
-					guint prop_id,
-					GValue *value,
-					GParamSpec *pspec);
+static void     kz_downloader_class_init   (KzDownloaderClass *klass);
+static void     kz_downloader_init         (KzDownloader *downloader);
+static void     kz_downloader_dispose      (GObject *object);
+static GObject *kz_downloader_constructor  (GType type,
+					    guint n_props,
+					    GObjectConstructParam *props);
+static void     kz_downloader_set_property (GObject *object,
+	            			    guint prop_id,
+	            			    const GValue *value,
+	            			    GParamSpec *pspec);
+static void     kz_downloader_get_property (GObject *object,
+					    guint prop_id,
+					    GValue *value,
+					    GParamSpec *pspec);
 
 static void kz_downloader_connect_signals    (KzDownloader *downloader);
 static void kz_downloader_disconnect_signals (KzDownloader *downloader);
@@ -81,6 +82,7 @@ kz_downloader_class_init (KzDownloaderClass *klass)
 	parent_class = g_type_class_peek_parent (klass);
 	object_class = (GObjectClass *) klass;
 
+	object_class->constructor  = kz_downloader_constructor;
 	object_class->dispose      = kz_downloader_dispose;
 	object_class->set_property = kz_downloader_set_property;
 	object_class->get_property = kz_downloader_get_property;
@@ -101,7 +103,8 @@ kz_downloader_class_init (KzDownloaderClass *klass)
 			 _("URI"),
 			 _("The URI of Target"),
 			 NULL,
-			 G_PARAM_READWRITE));
+			 G_PARAM_READWRITE |
+			 G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property(
 		object_class,
 		 PROP_FILENAME,
@@ -111,15 +114,6 @@ kz_downloader_class_init (KzDownloaderClass *klass)
 			 _("The Local Filename"),
 			 NULL,
 			 G_PARAM_READWRITE));
-	g_object_class_install_property(
-		object_class,
-		PROP_IO,
-		g_param_spec_object (
-			"io",
-			_("KzIO"),
-			_("The KzIO to communicate"),
-			KZ_TYPE_IO,
-			G_PARAM_READWRITE));
 
 	kz_downloader_signals[START_SIGNAL]
 		= g_signal_new ("start",
@@ -165,6 +159,30 @@ kz_downloader_init (KzDownloader *downloader)
 }
 
 
+static GObject*
+kz_downloader_constructor (GType                  type,
+			   guint                  n_props,
+			   GObjectConstructParam *props)
+{
+	KzDownloader *dl;
+	KzIO *io;
+	GObject *object;
+	GObjectClass *klass = G_OBJECT_CLASS(parent_class);
+
+	object = klass->constructor(type, n_props, props);
+
+	dl = KZ_DOWNLOADER(object);
+
+	io = kz_io_new(dl->uri);
+
+	if(!io)
+		return object;
+	
+	dl->io = io;
+
+	return object;
+}
+
 static void
 kz_downloader_dispose (GObject *object)
 {
@@ -197,18 +215,13 @@ kz_downloader_set_property (GObject *object,
 	switch (prop_id)
 	{
 	case PROP_URI:
-		g_free(downloader->uri);
 		downloader->uri = g_value_dup_string(value);
 		break;
 	case PROP_FILENAME:
-		g_free(downloader->filename);
+		if (downloader->filename)
+			g_free(downloader->filename);
 		downloader->filename = g_value_dup_string(value);
 		break;
-	case PROP_IO:
-		if (downloader->io)
-			g_object_unref(downloader->io);
-		downloader->io = g_object_ref(g_value_get_object(value));
-		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 		break;
@@ -232,9 +245,6 @@ kz_downloader_get_property (GObject *object,
 	case PROP_FILENAME:
 		g_value_set_string(value, downloader->filename);
 		break;
-	case PROP_IO:
-		g_value_set_object(value, downloader->io);
-		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 		break;
@@ -246,18 +256,17 @@ KzDownloader *
 kz_downloader_new (const gchar *uri)
 {
 	KzDownloader *dl;
-	KzIO *io;
-	
-	io = kz_io_new(uri);
-	if(!io)
-		return NULL;
 	
 	dl = g_object_new(KZ_TYPE_DOWNLOADER,
 		 	  "uri", uri,
-			  "io",  io,
 			  NULL);
-
-	g_object_unref(io);
+	
+	/* FIXME! */
+	if (!dl->io)
+	{
+		g_object_unref(dl);
+		return NULL;
+	}
 
 	return dl;
 }
@@ -267,18 +276,18 @@ KzDownloader *
 kz_downloader_new_with_filename (const gchar *uri, const gchar *filename)
 {
 	KzDownloader *dl;
-	KzIO *io;
-	
-	io = kz_io_new(uri);
-	if(!io)
-		return NULL;
-	
+
 	dl = g_object_new(KZ_TYPE_DOWNLOADER,
 			  "uri",      uri,
 			  "filename", filename,
-			  "io",       io,
 			  NULL);
-	g_object_unref(io);
+
+	/* FIXME! */
+	if (!dl->io)
+	{
+		g_object_unref(dl);
+		return NULL;
+	}
 
 	return dl;
 }
