@@ -1058,6 +1058,14 @@ kz_embed_get_allow_images (KzEmbed *kzembed)
 	return KZ_EMBED_GET_IFACE(kzembed)->get_allow_images(kzembed);
 }
 
+void
+kz_embed_show_page_certificate (KzEmbed *kzembed)
+{
+	g_return_if_fail(KZ_IS_EMBED(kzembed));
+	g_return_if_fail(KZ_EMBED_GET_IFACE(kzembed)->show_page_certificate);
+
+	return KZ_EMBED_GET_IFACE(kzembed)->show_page_certificate(kzembed);
+}
 
 static gchar *
 kz_embed_get_up_location(KzEmbed *kzembed)
