@@ -88,6 +88,10 @@ struct _KzWindowPrivate
 	gint start_x, start_y;
 	gboolean is_gesture;
 
+	/* for scroll */
+	gint is_button3_pressed;
+	gint is_button3_scrolled;
+	
 	/* sidebar */
 	gboolean sidebar_was_shown;
 
@@ -296,6 +300,9 @@ static gboolean cb_window_motion_notify_event  (GtkWidget      *widget,
 static gboolean cb_window_button_release_event (GtkWidget      *widget,
 						GdkEventButton *event,
 						KzEmbed        *kzembed);
+static gboolean cb_window_scroll_event         (GtkWidget      *widget,
+						GdkEventScroll *event,
+						KzEmbed        *kzembed);
 
 /* notebook received dropped url */
 static void     cb_notebook_drag_data_received (GtkWidget        *widget,
@@ -416,7 +423,9 @@ kz_window_init (KzWindow *kz)
 	kz->find_area          = kz_entry_new_with_stock(GTK_STOCK_FIND, GTK_ICON_SIZE_MENU);
 	kz->find_direction     = gtk_toggle_button_new();
 	kz->dlbox              = kz_download_box_new(kz);
-	kz->feed_info          = kz_feed_info_new(kz);
+	kz->grip_box           = gtk_statusbar_new();
+
+	kz->feed_info          = g_object_ref(kz_feed_info_new(kz));
 
 	kz->menu_merge         = gtk_ui_manager_new();
 	accel_group            = gtk_ui_manager_get_accel_group(kz->menu_merge);
@@ -442,6 +451,9 @@ kz_window_init (KzWindow *kz)
 	priv->start_y      = 0;
 	priv->is_gesture   = FALSE;
 
+	priv->is_button3_pressed  = FALSE;
+	priv->is_button3_scrolled = FALSE;
+	
 	priv->sidebar_was_shown = FALSE;
 
 	priv->open_hist    = NULL;
@@ -658,18 +670,16 @@ kz_window_init (KzWindow *kz)
 		priv->find_tips[1] = tips;
 	}
 
-	/* feed info */
+	/* grip box */
 	{
-		gtk_widget_set_size_request(kz->feed_info, 64, -1);
-		gtk_statusbar_set_has_resize_grip(GTK_STATUSBAR(kz->feed_info),
+		/* Why 18?
+		   Because gtk_status_bar's max grip width is 18. */
+		gtk_widget_set_size_request(kz->grip_box, 18, -1);
+		gtk_statusbar_set_has_resize_grip(GTK_STATUSBAR(kz->grip_box),
 						  TRUE);
-		gtk_box_pack_end(GTK_BOX(kz->statusbar_area), kz->feed_info,
+		gtk_box_pack_end(GTK_BOX(kz->statusbar_area), kz->grip_box,
 				 FALSE, FALSE, 0);
-		gtk_widget_show(kz->feed_info);
-	}
-
-	/* separator */
-	{
+		gtk_widget_show(kz->grip_box);
 		vseparator = gtk_vseparator_new();
 		gtk_box_pack_end(GTK_BOX(kz->statusbar_area), vseparator,
 				 FALSE, FALSE, 0);
@@ -806,6 +816,12 @@ kz_window_sync_ui_level (KzWindow *kz)
 
 	if (priv->merge_id != 0)
 	{
+		/* remove feed_info explicitly */
+		GtkWidget *menu_bar;
+		menu_bar = gtk_ui_manager_get_widget(kz->menu_merge,
+						     "/menubar");
+		gtk_container_remove(GTK_CONTAINER(menu_bar), kz->feed_info);
+
 		gtk_ui_manager_remove_ui(kz->menu_merge, priv->merge_id);
 		priv->merge_id = 0;
 		kz_actions_remove_smartbookmarks(kz, kz_bookmarks->smarts);
@@ -865,7 +881,18 @@ kz_window_sync_ui_level (KzWindow *kz)
 							      kz->closed_tabs);
 		}
 	}
-        
+
+	/* feed info */
+	{
+		GtkWidget *menu_bar;
+		menu_bar = gtk_ui_manager_get_widget(kz->menu_merge,
+						     "/menubar");
+
+		gtk_container_add(GTK_CONTAINER(menu_bar), kz->feed_info);
+		gtk_menu_item_set_right_justified(GTK_MENU_ITEM(kz->feed_info),
+						  TRUE);
+	}
+
 	/* update proxy */
 	kz_window_sync_proxy(kz);
 
@@ -1519,6 +1546,10 @@ kz_window_destroy (GtkObject *object)
 		kz_embed_event_free((KzEmbedEvent *) priv->event);
 	priv->event = NULL;
 
+	if (kz->feed_info)
+		g_object_unref(kz->feed_info);
+	kz->feed_info = NULL;
+
 	if (priv->find_tips[0])
 		g_object_unref(priv->find_tips[0]);
 	priv->find_tips[0] = NULL;
@@ -1896,6 +1927,9 @@ kz_window_set_cur_embed_callbacks(KzWindow *kz, KzEmbed *kzembed)
 	g_signal_connect(kz,
 			 "button_release_event",
 			 G_CALLBACK(cb_window_button_release_event), kzembed);
+	g_signal_connect(kz,
+			 "scroll_event",
+			 G_CALLBACK(cb_window_scroll_event), kzembed);
 
 	/*
 	 * key event signal
@@ -1948,6 +1982,9 @@ kz_window_unset_cur_embed_callbacks(KzWindow *kz, KzEmbed *kzembed)
 	g_signal_handlers_disconnect_by_func
 		(kz,
 		 G_CALLBACK(cb_window_button_release_event), kzembed);
+	g_signal_handlers_disconnect_by_func
+		(kz,
+		 G_CALLBACK(cb_window_scroll_event), kzembed);
 
 	/*
 	 * key event signal
@@ -2622,14 +2659,13 @@ cb_gesture_stack_motion (KzGesture *gesture, KzGestureMotion motion,
 
 
 static gboolean
-cb_notebook_scroll_event (GtkWidget *widget, GdkEventScroll *event,
-			  KzWindow *kz)
+handle_scroll_event (KzWindow *kz, GdkScrollDirection direction)
 {
 	GtkAction *action;
 
 	g_return_val_if_fail(KZ_IS_WINDOW(kz), FALSE);
 
-	switch (event->direction) {
+	switch (direction) {
 	case GDK_SCROLL_UP:
 	case GDK_SCROLL_LEFT:
 		action = gtk_action_group_get_action(kz->actions, "PrevTab");
@@ -2650,6 +2686,13 @@ cb_notebook_scroll_event (GtkWidget *widget, GdkEventScroll *event,
 	return FALSE;
 }
 
+static gboolean
+cb_notebook_scroll_event (GtkWidget *widget, GdkEventScroll *event,
+			  KzWindow *kz)
+{
+	return handle_scroll_event (kz, event->direction);
+}
+
 
 static void
 cb_sidebar_map (GtkWidget *widget, GtkToggleAction *action)
@@ -3024,6 +3067,9 @@ cb_embed_dom_mouse_down (KzEmbed *kzembed, KzEmbedEventMouse *event,
 		gboolean use_gesture = TRUE;
 		gint x, y, win_x, win_y, win_x_pos, win_y_pos;
 
+		priv->is_button3_pressed = TRUE;
+		priv->is_button3_scrolled = FALSE;
+
 		priv->is_gesture = FALSE;
 		KZ_CONF_GET("Gesture", "use_gesture", use_gesture, BOOL);
 		if (!use_gesture)
@@ -3195,7 +3241,7 @@ cb_window_button_release_event (GtkWidget *widget,
 
 	if (kz_gesture_is_started(priv->gesture))
 	{
-		if (event->button == 3)
+		if (event->button == 3 && !priv->is_button3_scrolled)
 			kz_gesture_perform(priv->gesture);
 		else
 			kz_gesture_cancel(priv->gesture);
@@ -3203,12 +3249,22 @@ cb_window_button_release_event (GtkWidget *widget,
 				  STATUS_GESTURE);
 	}
 
-	if (!priv->is_gesture && event->button == 3)
+	if (!priv->is_gesture &&
+	    !priv->is_button3_scrolled &&
+	    event->button == 3)
 	{
 		kz_actions_popup_menu_modal (kz, event->button, event->time);
 		retval = TRUE;
 	}
 
+	if (event->button == 3)
+	{
+		if (priv->is_button3_scrolled)
+			retval = TRUE;
+		priv->is_button3_pressed = FALSE;
+		priv->is_button3_scrolled = FALSE;
+	}
+	
 	priv->start_x = 0;
 	priv->start_y = 0;
 	priv->is_gesture = FALSE;
@@ -3220,6 +3276,28 @@ cb_window_button_release_event (GtkWidget *widget,
 	return retval;
 }
 
+static gboolean
+cb_window_scroll_event (GtkWidget *widget,
+			GdkEventScroll *event,
+			KzEmbed *kzembed)
+{
+	KzWindow *kz;
+	gboolean retval = FALSE;
+	KzWindowPrivate *priv;
+
+	g_return_val_if_fail(KZ_IS_EMBED(kzembed), FALSE);
+
+	kz = KZ_WINDOW(widget);
+	priv = KZ_WINDOW_GET_PRIVATE (kz);
+
+	if (priv->is_button3_pressed)
+	{
+		retval = handle_scroll_event (kz, event->direction);
+		priv->is_button3_scrolled = retval;
+	}
+	
+	return retval;
+}
 
 static void
 cb_notebook_drag_data_received (GtkWidget *widget,
@@ -3302,14 +3380,13 @@ cb_focus_out_event            (GtkWidget       *widget,
 		if (kz_gesture_is_started(priv->gesture))
 		{
 			kz_gesture_cancel(priv->gesture);
+			if (gdk_pointer_is_grabbed ())
+			{
+				gdk_pointer_ungrab (gtk_get_current_event_time ());
+			}
 			gtk_statusbar_pop(GTK_STATUSBAR(KZ_WINDOW(widget)->statusbar),
 					  STATUS_GESTURE);
 		}
-
-		if (gdk_pointer_is_grabbed ())
-		{
-			gdk_pointer_ungrab (gtk_get_current_event_time ());
-		}
 	}
 	return FALSE;
 }
