@@ -29,6 +29,14 @@
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 
+#ifdef USE_SSL
+#include <gcrypt.h>
+#include <gnutls/gnutls.h> 
+#include <errno.h>
+#include <pthread.h>
+GCRY_THREAD_OPTION_PTHREAD_IMPL;
+#endif
+
 #include "kazehakase.h"
 #include "kz-icons.h"
 #include "kz-window.h"
@@ -384,8 +392,8 @@ activate_action(const gchar *text)
 			widget = KZ_WINDOW_CURRENT_PAGE(kz);
 		if (!widget)
 			break;
-		kztab = KZ_TAB_LABEL(gtk_notebook_get_tab_label(GTK_NOTEBOOK(kz->notebook)
-								, widget));
+		kztab = KZ_TAB_LABEL(gtk_notebook_get_tab_label(GTK_NOTEBOOK(kz->notebook),
+								widget));
 
 		action = gtk_action_group_get_action(kz->tabpop_actions,
 						     action_name);
@@ -639,6 +647,12 @@ open_app_info (void)
 	kz_icons_init();
 	mozilla_init();
 
+#ifdef USE_SSL
+        /* initialize gnutls. this function should be called once. */
+	gcry_control (GCRYCTL_SET_THREAD_CBS, &gcry_threads_pthread);
+	gnutls_global_init ();
+#endif
+
 	/* check existence of estindex */
 	estindex = g_find_program_in_path("estindex");
 	
@@ -713,95 +727,6 @@ close_app_info (void)
 	free_goption();
 }
 
-static gboolean
-restore_session (void)
-{
-	GList *list, *node;
-	gint pos = 0;
-	gchar *current_session;
-	KzBookmarkFile *tmp_bookmark;
-
-	/* reload from current session file */
-	current_session  = g_build_filename(g_get_home_dir(),
-					    "."PACKAGE,
-					    "current_session.xml",
-					     NULL);
-	if (!g_file_test(current_session, G_FILE_TEST_EXISTS))
-	{
-		g_free(current_session);
-		return FALSE;
-	}
-	tmp_bookmark = kz_bookmark_file_new(current_session,
-					   _("Current Session"),
-					   "XBEL");
-	g_free(current_session);
-	kz_bookmark_file_load(tmp_bookmark);
-	
-	list = kz_bookmark_get_children(KZ_BOOKMARK(tmp_bookmark));
-	if (!g_list_length(list))
-	{
-		g_list_free(list);
-		g_object_unref(tmp_bookmark);
-		return FALSE;
-	}
-	
-	/* remove old entry from kz_bookmarks->current_session */
-	kz_bookmark_remove_all(kz_bookmarks->current_session);
-
-	is_restoring_session = TRUE;
-	/* windows */
-	for (node = list; node; node = g_list_next(node))
-	{
-		GList *tabs, *tabnode;
-		KzWindow *window;
-		KzBookmark *window_bookmark = KZ_BOOKMARK(node->data);
-		tabs = kz_bookmark_get_children(window_bookmark);
-
-		window = KZ_WINDOW(kz_window_new(NULL));
-	       	/* 
-		 * gtk_window_pargse_geometry() needs to be called 
-		 * before gtk_widget_show().
-		 */ 
-		if(geometry_string)
-		{
-			gtk_window_parse_geometry(GTK_WINDOW(window),
-						  geometry_string);
-		}
-		gtk_widget_show(GTK_WIDGET(window));
-	
-		/* tabs */
-		for (tabnode = tabs; tabnode; tabnode = g_list_next(tabnode))
-		{
-			GtkWidget *widget;
-			KzTabLabel *kztab;
-			KzBookmark *child = KZ_BOOKMARK(tabnode->data);
-			widget = kz_window_open_new_tab_at_tail(window, NULL);
-			kztab = KZ_TAB_LABEL(gtk_notebook_get_tab_label(
-					     GTK_NOTEBOOK(window->notebook),
-					     widget));
-			kz_tab_label_set_history(KZ_TAB_LABEL(kztab), child);
-
-			if (kz_bookmark_get_lock(child))
-			{
-				kz_tab_label_set_lock(kztab, TRUE);
-			}
-			if (kz_bookmark_get_auto_refresh(child))
-			{
-				kz_tab_label_set_auto_refresh(kztab, TRUE);
-			}
-		}
-		g_list_free(tabs);
-		pos = kz_bookmark_get_current(window_bookmark);
-		gtk_notebook_set_current_page(GTK_NOTEBOOK(window->notebook), pos);
-	}
-
-	g_list_free(list);
-	g_object_unref(tmp_bookmark);
-
-	is_restoring_session = FALSE;
-
-	return TRUE;
-}
 
 int
 main (int argc, char *argv[])
@@ -809,10 +734,9 @@ main (int argc, char *argv[])
 	KzWindow *kz = NULL;
 	GtkWidget *dupl_check_server = NULL;
 	gchar **argv_copy;
-	gint argc_copy = argc;
+	gint argc_copy;
 	gboolean retval;
 	GError *error = NULL;
-	gboolean restore = FALSE;
 
         /* initialize */
 	setlocale(LC_ALL, "");
@@ -837,6 +761,7 @@ main (int argc, char *argv[])
 
         /* copy argv (ant argc) so as to preserve original arguments */
 	argv_copy = g_strdupv(argv);
+	argc_copy = argc;
 
         /* g_option_context_parse changes argc_copy and argv_copy so as to
 	   process remaining arguments */
@@ -862,34 +787,20 @@ main (int argc, char *argv[])
 
 	/* Load preference */
 	open_app_info();
-	
-	/* restore session */
-	KZ_CONF_GET("Session", "restore",
-		    restore, BOOL);
-	if (restore)
-	{
-		GList *window_list;
-		restore = restore_session();
-		window_list = kz_window_get_window_list();
-		if (window_list)
-			kz = KZ_WINDOW(window_list->data);
-	}
-	if (!restore)
-	{
-		/* create window */	
-		kz = KZ_WINDOW(kz_window_new(NULL));
 
-	       	/* 
-		 * gtk_window_pargse_geometry() needs to be called 
-		 * before gtk_widget_show().
-		 */ 
-		if(geometry_string)
-		{
-			gtk_window_parse_geometry(GTK_WINDOW(kz),
-						  geometry_string);
-		}
-		gtk_widget_show(GTK_WIDGET(kz));
+	/* create window */	
+	kz = KZ_WINDOW(kz_window_new(NULL));
+
+       	/* 
+	 * gtk_window_pargse_geometry() needs to be called 
+	 * before gtk_widget_show().
+	 */ 
+	if(geometry_string)
+	{
+		gtk_window_parse_geometry(GTK_WINDOW(kz),
+					  geometry_string);
 	}
+	gtk_widget_show(GTK_WIDGET(kz));
 
 	/* process arguments */
 	process_args(argc_copy, argv_copy);
@@ -901,6 +812,9 @@ main (int argc, char *argv[])
 	/* exit */
 	gtk_widget_destroy(dupl_check_server);
 	dupl_check_server = NULL;
+#ifdef USE_SSL
+	gnutls_global_deinit ();
+#endif
 
 	close_app_info();
 
