@@ -27,6 +27,11 @@
 #include "kz-mozembed.h"
 
 #include <nsIDOMEventListener.h>
+#include <nsCOMPtr.h>
+#include <nsIDOMElement.h>
+#define MOZILLA_STRICT_API
+#include <nsEmbedString.h>
+#undef MOZILLA_STRICT_API
 
 class KzMozEventListener : public nsIDOMEventListener
 {
@@ -43,6 +48,9 @@ class KzMozEventListener : public nsIDOMEventListener
 	KzMozEmbed *mOwner;
 
 	nsresult HandleLink        (nsIDOMNode *node);
+	nsresult GetLinkAttribute  (nsCOMPtr<nsIDOMElement>& linkElement,
+				    const char *name,
+				    nsEmbedString *value);
 };
 
 #endif /* __KZ_MOZ_EVENT_LISTENER_H__ */
